# OX App Suite SOAP provisioning tests
These tests use the SOAP provisioning interface of OX App Suite and cover each request.

## Prerequisites
Efficiently working with this test project requires a commercial license of ReadyAPI (http://smartbear.com/product/ready-api/overview/) for the test execution environment.

## Test and Target environment
Usually tests are executed on a test execution host and remotely connect to a target environment which runs the application under test, OX App Suite. However, it's also possible to execute these tests on the target environment.

* Test environment: Host where tests are being started
* Target environment: Host which runs the application under test

## Setting up the target environment
To run the tests, some configuration changes are required on the target environment:

1. Install optional packages

    `apt-get install open-xchange-admin-soap-usercopy open-xchange-passwordchange-database`

2. Create directories for additional local filestores

    `mkdir /var/opt/filestore{2,3}`

3. Make sure the OX database user is able to access newly created schemas with a specific name

    `mysql -p`
    ``mysql> GRANT ALL PRIVILEGES ON `testdb_%`.* TO 'openexchange'@'localhost';``

4. Configure the load-balancer or web server to allow the test environment to access the `/webservices` path, which serves the provisioning interfaces.

    For that, look at the `Allow from...` area for `/webservices` at `ox-proxy_http.conf` and adjust it accordingly.

5. Restart the web-server

    `service apache2 restart`

6. Modify the default provisioning configuration

    `sed -i 's/USERNAME_CHANGEABLE=false/USERNAME_CHANGEABLE=true/g' /opt/open-xchange/etc/AdminUser.properties`

    `sed -i 's/PRIMARY_MAIL_UNCHANGEABLE=true/PRIMARY_MAIL_UNCHANGEABLE=false/g' /opt/open-xchange/etc/AdminUser.properties`

7. Restart OX AppSuite

    `service open-xchange restart`

8. Remove contexts
To avoid side-effects and conflicts, please make sure no contexts exist before running tests.

### Reseller configuration for target environment
In case the target environment shall be configured for reseller usage, additional packages and configuration is required. Note that once reseller configuration is active, the behaviour of the target environment will change and only tests from the reseller-specific project can be executed.

1. Install the SOAP interface for reseller services

    `apt-get install open-xchange-admin-soap-reseller`

2. Import database schema changes to configdb (< 7.10.2 only)

    `mysql -u openexchange -psecret configdb < /opt/open-xchange/etc/mysql/reseller.sql`
    `mysql -u openexchange -psecret configdb < /opt/open-xchange/etc/mysql/autocid.sql`

3. Restart and initialize reseller configuration

    `service open-xchange restart`
    
    `/opt/open-xchange/sbin/initrestrictions -A oxadminmaster -P secret`

## Setting up the test environment
1. After installing an running ReadyAPI, use `File -> Import Composite Project` and select the directory of the `main` or `reseller` project. Use `Choose` to import the project.
2. Now select the projects root folder, for example `main` or `reseller` and use `Choose`.
3. The project should now be expandable and show the included endpoints.
4. Select the `SoapUI` tab, select the project and locate the `Project Properties` box.
5. Select `Custom Properties` and adjust `ServiceEndpoint`, `HTTPAPIEndpoint` and `HTTPSAPIEndpoint` to match the target environment.
